@@ -14,6 +14,7 @@ import os
 from os.path import join
 import re
 import sys
+import warnings
 
 if sys.hexversion < 0x02070000:
     import unittest2 as unittest
@@ -36,8 +37,6 @@ except KeyError:
 
 @unittest.skipIf(FORMAT_CORPUS_DATA_ROOT is None,
                  "FORMAT_CORPUS_DATA_ROOT environment variable not set")
-@unittest.skipIf(sys.hexversion < 0x03020000,
-                 "Requires features introduced in 3.2 (assertWarns)")
 class TestSuiteFormatCorpus(unittest.TestCase):
     """Test suite for files in format corpus repository."""
 
@@ -49,32 +48,16 @@ class TestSuiteFormatCorpus(unittest.TestCase):
         jfile = os.path.join(FORMAT_CORPUS_DATA_ROOT,
                              'jp2k-test/byteCorruption/balloon_trunc1.jp2')
         j2k = Jp2k(jfile)
-        with self.assertWarns(UserWarning):
+        with warnings.catch_warnings(record=True) as w:
+            warnings.simplefilter("always")
             codestream = j2k.get_codestream(header_only=False)
+            self.assertEqual(len(w), 1)
 
         # The last segment is truncated, so there should not be an EOC marker.
         self.assertNotEqual(codestream.segment[-1].marker_id, 'EOC')
 
         # The codestream is not as long as claimed.
-        with self.assertRaises(OSError):
-            j2k.read(rlevel=-1)
-
-    @unittest.skipIf(re.match(r"""1\.[01234]""",
-                              glymur.version.openjpeg_version) is not None,
-                     "Needs 1.4+ to catch this.")
-    def test_balloon_trunc2(self):
-        """Shortened by 5000 bytes."""
-        jfile = os.path.join(FORMAT_CORPUS_DATA_ROOT,
-                             'jp2k-test/byteCorruption/balloon_trunc2.jp2')
-        j2k = Jp2k(jfile)
-        with self.assertWarns(UserWarning):
-            codestream = j2k.get_codestream(header_only=False)
-
-        # The last segment is truncated, so there should not be an EOC marker.
-        self.assertNotEqual(codestream.segment[-1].marker_id, 'EOC')
-
-        # The codestream is not as long as claimed.
-        with self.assertRaises(OSError):
+        with self.assertRaises((OSError, IOError)):
             j2k.read(rlevel=-1)
 
     def test_balloon_trunc3(self):
@@ -82,8 +65,10 @@ class TestSuiteFormatCorpus(unittest.TestCase):
         jfile = os.path.join(FORMAT_CORPUS_DATA_ROOT,
                              'jp2k-test/byteCorruption/balloon_trunc3.jp2')
         j2k = Jp2k(jfile)
-        with self.assertWarns(UserWarning):
+        with warnings.catch_warnings(record=True) as w:
+            warnings.simplefilter("always")
             codestream = j2k.get_codestream(header_only=False)
+            self.assertEqual(len(w), 1)
 
         # The last segment is truncated, so there should not be an EOC marker.
         self.assertNotEqual(codestream.segment[-1].marker_id, 'EOC')
@@ -97,8 +82,10 @@ class TestSuiteFormatCorpus(unittest.TestCase):
         jfile = os.path.join(FORMAT_CORPUS_DATA_ROOT,
                              'jp2k-test', 'icc',
                              'balloon_eciRGBv2_ps_adobeplugin.jpf')
-        with self.assertWarns(UserWarning):
+        with warnings.catch_warnings(record=True) as w:
+            warnings.simplefilter("always")
             Jp2k(jfile)
+            self.assertEqual(len(w), 1)
 
     def test_jp2_brand_iccpr_mult_colr(self):
         """Has colr box, one that conforms, one that does not."""
@@ -109,14 +96,14 @@ class TestSuiteFormatCorpus(unittest.TestCase):
         # ("Input Device") changed relative to original profile.
         jfile = join(FORMAT_CORPUS_DATA_ROOT, 'jp2k-test', 'icc',
                      'balloon_eciRGBv2_ps_adobeplugin_jp2compatible.jpf')
-        with self.assertWarns(UserWarning):
+        with warnings.catch_warnings(record=True) as w:
+            warnings.simplefilter("always")
             Jp2k(jfile)
+            self.assertEqual(len(w), 1)
 
 
 @unittest.skipIf(OPJ_DATA_ROOT is None,
                  "OPJ_DATA_ROOT environment variable not set")
-@unittest.skipIf(sys.hexversion < 0x03020000,
-                 "Requires features introduced in 3.2 (assertWarns)")
 class TestSuiteOpj(unittest.TestCase):
     """Test suite for files in openjpeg repository."""
 
@@ -130,8 +117,10 @@ class TestSuiteOpj(unittest.TestCase):
         """If 'jp2 ', then the method cannot be any icc profile."""
         filename = os.path.join(OPJ_DATA_ROOT,
                                 'input/nonregression/text_GBR.jp2')
-        with self.assertWarns(UserWarning):
+        with warnings.catch_warnings(record=True) as w:
+            warnings.simplefilter("always")
             Jp2k(filename)
+            self.assertEqual(len(w), 1)
 
 if __name__ == "__main__":
     unittest.main()
